@@ -40,12 +40,21 @@
  *	Author: Sasha K (sashak@smlink.com)
  *
  */
-
+ 
+ /*
+  *	20070505: -Added Motorola Venor ID and rename Motorola device 5600
+  * http://linmodems.technion.ac.il/bigarch/archive-seventh/msg00846.html
+  * Marvin Stodolsky (marvin.stodolsky@gmail.com)
+  * Alvaro Aguirre (alvaro.aguirre@gmail.com)
+  */
+ 
 /*****************************************************************************/
 
-#include <linux/config.h>
-#include <linux/module.h>
 #include <linux/version.h>
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
+#include <linux/config.h>
+#endif
+#include <linux/module.h>
 #include <linux/init.h>
 #include <linux/pci.h>
 #include <linux/kernel.h>
@@ -53,13 +62,13 @@
 #include <linux/poll.h>
 #include <linux/fs.h>
 #include <asm/uaccess.h>
-#include <linux/devfs_fs_kernel.h>
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,5,0)
 #define OLD_KERNEL 1
 #endif
 
 #ifdef OLD_KERNEL
+#include <linux/devfs_fs_kernel.h>
 #define iminor(i) MINOR((i)->i_rdev)
 #else
 #include <linux/device.h>
@@ -140,6 +149,7 @@
 #define PCI_VENDOR_ID_SMARTLINK_1		0x163c
 #define PCI_VENDOR_ID_SMARTLINK_2		0x10a5
 #define PCI_VENDOR_ID_SMARTLINK_3		0x2003
+#define PCI_VENDOR_ID_SL1543 			0x1543 /* for Motorola Subsytem */
 #define PCI_DEVICE_ID_SL2800			0x2800
 #define PCI_DEVICE_ID_SL1900			0x3052
 #define PCI_DEVICE_ID_ND92XPA                   0x8800 /* ND92XPA */
@@ -147,6 +157,9 @@
 #define PCI_VENDOR_ID_PCTEL                     0x134d
 #define PCI_DEVICE_ID_HSP1688                   0x2189
 
+/* Motorola section */
+#define PCI_VENDOR_ID_MOTOROLA                  0x1057
+
 enum {
 	ALS300_CARD = 1,
 	VIA3058_CARD,
@@ -160,6 +173,7 @@ enum {
 	RTL8197_CARD,
 	NVIDIA_CARD,
 	SL1500_CARD,
+	SL1543_CARD,
 	SL1801_CARD,
 	SL1900_CARD,
 	SL2800_CARD
@@ -218,6 +232,7 @@ static const char *card_names[] = {
 	"RealTek8101",
 	"NvidiaMCP",
 	"SL1500",
+	"SL1543"
 	"ALI545A",
 	"SL1900",
 	"SL2800"
@@ -225,6 +240,10 @@ static const char *card_names[] = {
 
 
 static struct pci_device_id amrmo_pci_tbl [] __devinitdata = {
+	{PCI_VENDOR_ID_SL1543, PCI_DEVICE_ID_SL1900,
+	 PCI_ANY_ID, PCI_ANY_ID, 0, 0, SL1900_CARD},       /* 1543:3052 , Motorola 1543:3000 */
+	{PCI_VENDOR_ID_MOTOROLA, PCI_DEVICE_ID_SL1900,     /* Motorola 1057:3052 */
+	 PCI_ANY_ID, PCI_ANY_ID, 0, 0, SL1900_CARD},
 	{PCI_VENDOR_ID_SMARTLINK_1, PCI_DEVICE_ID_SL1900,  /* 163c:3052 */
 	 PCI_ANY_ID, PCI_ANY_ID, 0, 0, SL1900_CARD},
 	{PCI_VENDOR_ID_SMARTLINK_2, PCI_DEVICE_ID_SL1900,  /* 10a5:3052 */
@@ -286,6 +305,7 @@ static struct pci_device_id amrmo_pci_tbl [] __devinitdata = {
 	 PCI_ANY_ID, PCI_ANY_ID, 0, 0, SL2800_CARD},
 	{PCI_VENDOR_ID_SMARTLINK_3, PCI_DEVICE_ID_ND92XPA, /* 2003:8800 */
 	 PCI_ANY_ID, PCI_ANY_ID, 0, 0, SL2800_CARD},
+	 
 	{0,}
 };
 
@@ -501,7 +521,11 @@ static void amrmo_pci_interrupt(int irq, void *dev_id, struct pt_regs *regs)
 	amrmo_card_interrupt(amrmo->card);
 }
 #else
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
 static irqreturn_t amrmo_pci_interrupt(int irq, void *dev_id, struct pt_regs *regs)
+#else
+static irqreturn_t amrmo_pci_interrupt(int irq, void *dev_id)
+#endif
 {
         struct amrmo_struct *amrmo = (struct amrmo_struct *)dev_id;
 	amrmo_card_interrupt(amrmo->card);
@@ -641,7 +665,6 @@ static int __init amrmo_pci_probe(struct pci_dev *pci_dev, const struct pci_devi
 #endif
 #else
 	class_simple_device_add(amrmo_class, MKDEV(AMRMO_MAJOR, i), NULL, "slamr%d", i);
-	devfs_mk_cdev(MKDEV(AMRMO_MAJOR,i), S_IFCHR|S_IRUSR|S_IWUSR, "slamr%d", i);
 #endif
 	return 0;
 
@@ -673,7 +696,6 @@ static void __exit amrmo_pci_remove(struct pci_dev *pci_dev)
 #endif
 #else
 	class_simple_device_remove(MKDEV(AMRMO_MAJOR, amrmo->num));
-	devfs_remove("slamr%d", amrmo->num);
 #endif
 	amrmo_table[amrmo->num] = NULL;
 	amrmo_card_disable(amrmo->card);
@@ -701,7 +723,7 @@ static struct pci_driver amrmo_pci_driver = {
  *  module stuff
  */
 
-MODULE_PARM(debug,"i");
+module_param(debug, int, 1);
 MODULE_PARM_DESC(debug,"debug level: 0-3 (default=0)");
 
 MODULE_AUTHOR("Smart Link Ltd.");
@@ -802,5 +824,3 @@ module_exit(amrmo_exit);
 #ifdef OLD_KERNEL
 EXPORT_NO_SYMBOLS;
 #endif
-
-
