@@ -55,7 +55,6 @@
 #include <linux/poll.h>
 #include <linux/usb.h>
 #include <linux/device.h>
-#include <linux/devfs_fs_kernel.h>
 
 #include <modem_defs.h>
 
@@ -76,7 +75,8 @@
 #define USB_DBG_URB(fmt...) // USB_DBG(fmt)
 
 static int debug = 0;
-MODULE_PARM(debug,"i");
+
+module_param(debug, int, 1);
 MODULE_PARM_DESC(debug,"Debug level: 0-3 (default=0)");
 
 /* st7554 IDs */
@@ -396,7 +396,11 @@ static int mo_init (struct st7554_state *s)
 /* ----------------------------------------------------------------------- */
 
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
 static void st7554_interrupt(struct urb *urb, struct pt_regs* regs)
+#else
+static void st7554_interrupt(struct urb *urb)
+#endif
 {
 	struct st7554_state *s = urb->context;
 	u32 *status = urb->transfer_buffer;
@@ -437,7 +441,11 @@ static void st7554_interrupt(struct urb *urb, struct pt_regs* regs)
 /* --------------------------------------------------------------------- */
 
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
 static void mo_complete(struct urb *u, struct pt_regs* regs)
+#else
+static void mo_complete(struct urb *u)
+#endif
 {
 	struct st7554_state *s = u->context;
 	struct dmabuf *db = &s->mo.dma;
@@ -496,14 +504,22 @@ static void mo_complete(struct urb *u, struct pt_regs* regs)
 }
 
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
 static void mo_startup_complete(struct urb *u, struct pt_regs* regs)
+#else
+static void mo_startup_complete(struct urb *u)
+#endif
 {
 	struct st7554_state *s = u->context;
 	USB_DBG("mo_startup_complete %d: %d: sent %d.\n",
 		MO_URB_NO(s,u), u->start_frame, u->actual_length);
 	FILL_DESC_OUT(s,&s->mo,u,BYTES_IN_FRAMES(s,DESCFRAMES));
 	u->complete = mo_complete;
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
 	mo_complete(u,regs);
+#else
+	mo_complete(u);
+#endif
 	complete(&s->start_comp);
 }
 
@@ -511,7 +527,11 @@ static void mo_startup_complete(struct urb *u, struct pt_regs* regs)
 /* ----------------------------------------------------------------------- */
 
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
 static void mi_complete(struct urb *u, struct pt_regs* regs)
+#else
+static void mi_complete(struct urb *u)
+#endif
 {
 	struct st7554_state *s = u->context;
 	struct urb *next;
@@ -556,7 +576,11 @@ static void mi_complete(struct urb *u, struct pt_regs* regs)
 }
 
 
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,19)
 static void mi_startup_complete(struct urb *u, struct pt_regs* regs)
+#else
+static void mi_startup_complete(struct urb *u)
+#endif
 {
 	struct st7554_state *s = u->context;
 	struct usb_iso_packet_descriptor *p;
@@ -1150,7 +1174,9 @@ static struct usb_device_id st7554_ids [] = {
 MODULE_DEVICE_TABLE (usb, st7554_ids);
 
 static struct usb_driver st7554_usb_driver = {
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,15)
 	.owner =       THIS_MODULE,
+#endif
 	.name =	       "ST7554 USB Modem",
 	.probe =       st7554_probe,
 	.disconnect =  st7554_disconnect,
@@ -1283,7 +1309,6 @@ static int st7554_probe(struct usb_interface *interface,
 
 	usb_set_intfdata(interface, s );
 	class_simple_device_add(st7554_class, MKDEV(243, i), NULL, "slusb%d", i);
-	devfs_mk_cdev(MKDEV(243,i),S_IFCHR|S_IRUSR|S_IWUSR,"slusb%d",i);
 
 	USB_INFO(KERN_INFO "slusb: slusb%d is found.\n", s->minor);
 
@@ -1312,7 +1337,6 @@ static void st7554_disconnect(struct usb_interface *interface)
         }
 
 	class_simple_device_remove(MKDEV(243, s->minor));
- 	devfs_remove("slusb%d",s->minor);
 
 	st7554_stop(s);
 	down(&open_sem);
